@@ -30,8 +30,6 @@
 #include "fancytabwidget.h"
 #include "stylehelper.h"
 
-#include <QDebug>
-
 #include <QAnimationGroup>
 #include <QColorDialog>
 #include <QHBoxLayout>
@@ -474,7 +472,7 @@ void FancyTabBar::setCurrentIndex(int index)
 // FancyColorButton
 //////
 
-class QT_QUPZILLA_EXPORT FancyColorButton : public QWidget
+class QUPZILLA_EXPORT FancyColorButton : public QWidget
 {
 public:
     FancyColorButton(QWidget* parent)
