@@ -32,12 +32,14 @@
 #include "browsinglibrary.h"
 #include "clearprivatedata.h"
 #include "qzsettings.h"
+#include "pluginproxy.h"
 
 #include <QApplication>
 #include <QMetaObject>
 #include <QStatusBar>
 #include <QWebPage>
 #include <QMenuBar>
+#include <QDesktopServices>
 
 #ifdef Q_OS_MAC
 extern void qt_mac_set_dock_menu(QMenu* menu);
@@ -101,6 +103,9 @@ void MainMenu::initSuperMenu(QMenu* superMenu) const
     superMenu->addAction(m_actions[QSL("File/WorkOffline")]);
     superMenu->addSeparator();
     superMenu->addAction(m_actions[QSL("Standard/Quit")]);
+
+    connect(superMenu, SIGNAL(aboutToShow()), this, SLOT(aboutToShowSuperMenu()));
+    connect(superMenu, SIGNAL(aboutToHide()), this, SLOT(aboutToHideSuperMenu()));
 }
 
 QAction* MainMenu::action(const QString &name) const
@@ -175,9 +180,8 @@ void MainMenu::savePageScreen()
 
 void MainMenu::sendLink()
 {
-    if (m_window) {
-        m_window->weView()->savePageAs();
-    }
+    const QUrl mailUrl = QUrl::fromEncoded("mailto:%20?body=" + QUrl::toPercentEncoding(m_window->weView()->url().toEncoded()) + "&subject=" + QUrl::toPercentEncoding(m_window->weView()->title()));
+    QDesktopServices::openUrl(mailUrl);
 }
 
 void MainMenu::printPage()
@@ -336,9 +340,9 @@ void MainMenu::showRssManager()
     }
 }
 
-void MainMenu::showWebInspector()
+void MainMenu::toggleWebInspector()
 {
-    callSlot("showWebInspector");
+    callSlot("toggleWebInspector");
 }
 
 void MainMenu::showClearRecentHistoryDialog()
@@ -444,6 +448,11 @@ void MainMenu::aboutToHideEditMenu()
 void MainMenu::aboutToShowToolsMenu()
 {
     m_actions[QSL("Tools/SiteInfo")]->setEnabled(true);
+
+    m_submenuExtensions->clear();
+    mApp->plugins()->populateExtensionsMenu(m_submenuExtensions);
+
+    m_submenuExtensions->menuAction()->setVisible(!m_submenuExtensions->actions().isEmpty());
 }
 
 void MainMenu::aboutToHideToolsMenu()
@@ -451,6 +460,24 @@ void MainMenu::aboutToHideToolsMenu()
     m_actions[QSL("Tools/SiteInfo")]->setEnabled(false);
 }
 
+void MainMenu::aboutToShowSuperMenu()
+{
+    if (!m_window) {
+        return;
+    }
+
+    WebView* view = m_window->weView();
+
+    m_actions[QSL("Edit/Find")]->setEnabled(true);
+    m_actions[QSL("Edit/SelectAll")]->setEnabled(view->pageAction(QWebPage::SelectAll)->isEnabled());
+}
+
+void MainMenu::aboutToHideSuperMenu()
+{
+    m_actions[QSL("Edit/Find")]->setEnabled(true);
+    m_actions[QSL("Edit/SelectAll")]->setEnabled(false);
+}
+
 void MainMenu::aboutToShowToolbarsMenu()
 {
     QMenu* menu = qobject_cast<QMenu*>(sender());
@@ -598,8 +625,12 @@ void MainMenu::init()
     ADD_ACTION("Tools/CookiesManager", m_menuTools, QIcon(), tr("&Cookies Manager"), SLOT(showCookieManager()), "");
     ADD_ACTION("Tools/AdBlock", m_menuTools, QIcon(), tr("&AdBlock"), SLOT(showAdBlockDialog()), "");
     ADD_ACTION("Tools/RssReader", m_menuTools, QIcon(), tr("RSS &Reader"), SLOT(showRssManager()), "");
-    ADD_ACTION("Tools/WebInspector", m_menuTools, QIcon(), tr("Web In&spector"), SLOT(showWebInspector()), "Ctrl+Shift+I");
+    ADD_ACTION("Tools/WebInspector", m_menuTools, QIcon(), tr("Web In&spector"), SLOT(toggleWebInspector()), "Ctrl+Shift+I");
     ADD_ACTION("Tools/ClearRecentHistory", m_menuTools, QIcon::fromTheme(QSL("edit-clear")), tr("Clear Recent &History"), SLOT(showClearRecentHistoryDialog()), "Ctrl+Shift+Del");
+
+    m_submenuExtensions = new QMenu(tr("&Extensions"));
+    m_submenuExtensions->menuAction()->setVisible(false);
+    m_menuTools->addMenu(m_submenuExtensions);
     m_menuTools->addSeparator();
 
     // Help menu
