@@ -44,12 +44,14 @@ public:
     TabbedWebView* webView() const;
     void setWebView(TabbedWebView* view);
 
+    static QString convertUrlToText(const QUrl &url);
+
 public slots:
     void setText(const QString &text);
     void showUrl(const QUrl &url);
 
 private slots:
-    void textEditted();
+    void textEdited(const QString &text);
     void requestLoadUrl();
     void pasteAndGo();
 
@@ -88,7 +90,6 @@ private:
     void paintEvent(QPaintEvent* event);
 
     LoadRequest createLoadRequest() const;
-    QString convertUrlToText(const QUrl &url) const;
     void refreshTextFormat();
 
     LocationCompleter* m_completer;
@@ -108,7 +109,8 @@ private:
 
     bool m_rssIconVisible;
     bool m_holdingAlt;
-    bool m_backspacePressed;
+    int m_oldTextLength;
+    int m_currentTextLength;
 
     int m_loadProgress;
     bool m_progressVisible;
