@@ -190,7 +190,7 @@ QString QupZillaSchemeReply::startPage()
     sPage.append(QzTools::readAllFileContents(":html/start.html"));
     sPage.replace(QLatin1String("%FAVICON%"), QLatin1String("qrc:icons/qupzilla.png"));
     sPage.replace(QLatin1String("%BOX-BORDER%"), QLatin1String("qrc:html/box-border.png"));
-    sPage.replace(QLatin1String("%ABOUT-IMG%"), QLatin1String("qrc:icons/other/about.png"));
+    sPage.replace(QLatin1String("%ABOUT-IMG%"), QLatin1String("qrc:icons/other/startpage.png"));
 
     sPage.replace(QLatin1String("%TITLE%"), tr("Start Page"));
     sPage.replace(QLatin1String("%BUTTON-LABEL%"), tr("Search on Web"));
@@ -233,12 +233,13 @@ QString QupZillaSchemeReply::aboutPage()
         aPage.replace(QLatin1String("%CONTRIBUTORS%"), tr("Contributors"));
         aPage.replace(QLatin1String("%CONTRIBUTORS-TEXT%"),
                       authorString("Mladen Pejaković", "pejakm@autistici.org") + "<br/>" +
-                      authorString("Alexander Samilov", "alexsamilovskih@gmail.com") + "<br/>" +
+                      authorString("Adrien Vigneron", "adrienvigneron@ml1.net") + "<br/>" +
+                      authorString("Elio Qoshi", "ping@elioqoshi.me") + "<br/>" +
                       authorString("Seyyed Razi Alavizadeh", "s.r.alavizadeh@gmail.com") + "<br/>" +
+                      authorString("Alexander Samilov", "alexsamilovskih@gmail.com") + "<br/>" +
                       authorString("Franz Fellner", "alpine.art.de@googlemail.com") + "<br/>" +
                       authorString("Bryan M Dunsmore", "dunsmoreb@gmail.com") + "<br/>" +
                       authorString("Mariusz Fik", "fisiu@opensuse.org") + "<br/>" +
-                      authorString("Jan Rajnoha", "honza.rajny@hotmail.com")  + "<br/>" +
                       authorString("Daniele Cocca", "jmc@chakra-project.org")
                      );
         aPage.replace(QLatin1String("%TRANSLATORS%"), tr("Translators"));
@@ -268,7 +269,7 @@ QString QupZillaSchemeReply::aboutPage()
                       authorString("Beqa Arabuli", "arabulibeqa@gmail.com") + " (Georgian)<br/>" +
                       authorString("Daiki Noda", "sys.pdr.pdm9@gmail.com") + " (Japanese)<br/>" +
                       authorString("Gábor Oberle", "oberleg@myopera.com") + " (Hungarian)<br/>" +
-                      authorString("Piccoro McKay Lenz", "mckaygerhard@gmail.com") + " (Venezulean Spanish)<br/>" +
+                      authorString("Piccoro McKay Lenz", "mckaygerhard@gmail.com") + " (Venezuelan Spanish)<br/>" +
                       authorString("Stanislav Kuznietsov", "stanislav_kuznetsov@ukr.net") + " (Ukrainian)<br/>" +
                       authorString("Seyyed Razi Alavizadeh", "s.r.alavizadeh@gmail.com") + " (Persian)<br/>" +
                       authorString("Guillem Prats", "guprej@gmail.com") + " (Catalan)<br/>" +
@@ -338,7 +339,7 @@ QString QupZillaSchemeReply::speeddialPage()
     page.replace(QLatin1String("%B_SIZE%"), dial->backgroundImageSize());
     page.replace(QLatin1String("%ROW-PAGES%"), QString::number(dial->pagesInRow()));
     page.replace(QLatin1String("%SD-SIZE%"), QString::number(dial->sdSize()));
-    page.replace(QLatin1String("%SD-CNTR%"), QString::number(dial->sdCntr()));
+    page.replace(QLatin1String("%SD-CENTER%"), dial->sdCenter() ? QSL("true") : QSL("false"));
 
     return page;
 }
@@ -399,7 +400,6 @@ QString QupZillaSchemeReply::configPage()
                                                           ) +
                       QString("<dt>%1</dt><dd>%2<dd>").arg(tr("Qt version"), QT_VERSION_STR) +
                       QString("<dt>%1</dt><dd>%2<dd>").arg(tr("WebKit version"), qWebKitVersion()) +
-                      QString("<dt>%1</dt><dd>%2<dd>").arg(tr("Build time"), Qz::BUILDTIME) +
                       QString("<dt>%1</dt><dd>%2<dd>").arg(tr("Platform"), QzTools::operatingSystem()));
 
         cPage.replace(QLatin1String("%PATHS-TEXT%"),
