@@ -1,6 +1,6 @@
 /* ============================================================
 * QupZilla - WebKit based browser
-* Copyright (C) 2010-2013  David Rosca <nowrep@gmail.com>
+* Copyright (C) 2010-2014  David Rosca <nowrep@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -20,14 +20,14 @@
 
 #include <QDialog>
 
-#include "qz_namespace.h"
+#include "qzcommon.h"
 
 namespace Ui
 {
 class AboutDialog;
 }
 
-class QT_QUPZILLA_EXPORT AboutDialog : public QDialog
+class QUPZILLA_EXPORT AboutDialog : public QDialog
 {
     Q_OBJECT
 
@@ -45,6 +45,7 @@ private:
 
     QString m_aboutHtml;
     QString m_authorsHtml;
+    bool m_showingAuthors;
 };
 
 #endif // ABOUTDIALOG_H
