@@ -1,6 +1,6 @@
 /* ============================================================
 * QupZilla - WebKit based browser
-* Copyright (C) 2013  David Rosca <nowrep@gmail.com>
+* Copyright (C) 2013-2014  David Rosca <nowrep@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -20,14 +20,14 @@
 
 #include <QDialog>
 
-#include "qz_namespace.h"
+#include "qzcommon.h"
 
 namespace Ui
 {
 class SpellCheckDialog;
 }
 
-class QT_QUPZILLA_EXPORT SpellCheckDialog : public QDialog
+class QUPZILLA_EXPORT SpellCheckDialog : public QDialog
 {
     Q_OBJECT
 
