@@ -17,7 +17,7 @@
 * ============================================================ */
 #include "preferences.h"
 #include "ui_preferences.h"
-#include "qupzilla.h"
+#include "browserwindow.h"
 #include "bookmarkstoolbar.h"
 #include "history.h"
 #include "tabwidget.h"
@@ -41,12 +41,19 @@
 #include "qztools.h"
 #include "autofill.h"
 #include "settings.h"
+#include "datapaths.h"
 #include "tabbedwebview.h"
 #include "clearprivatedata.h"
 #include "useragentdialog.h"
 #include "registerqappassociation.h"
+#include "profilemanager.h"
 #include "html5permissions/html5permissionsdialog.h"
 #include "pac/pacmanager.h"
+#include "searchenginesdialog.h"
+
+#ifdef USE_HUNSPELL
+#include "qtwebkit/spellcheck/speller.h"
+#endif
 
 #include <QSettings>
 #include <QInputDialog>
@@ -55,6 +62,7 @@
 #include <QCloseEvent>
 #include <QColorDialog>
 #include <QDesktopWidget>
+#include <QNetworkDiskCache>
 
 static QString createLanguageItem(const QString &lang)
 {
@@ -63,17 +71,31 @@ static QString createLanguageItem(const QString &lang)
     QString country = QLocale::countryToString(locale.country());
     QString language = QLocale::languageToString(locale.language());
 
+    if (lang == QLatin1String("es_ES")) {
+        return QString::fromUtf8("Castellano");
+    }
     if (lang == QLatin1String("nqo")) {
         return QString("N'ko (nqo)");
     }
-
+    if (lang == QLatin1String("sr")) {
+        return QString::fromUtf8("српски екавски");
+    }
+    if (lang == QLatin1String("sr@ijekavian")) {
+        return QString::fromUtf8("српски ијекавски");
+    }
+    if (lang == QLatin1String("sr@latin")) {
+        return QString::fromUtf8("srpski ekavski");
+    }
+    if (lang == QLatin1String("sr@ijekavianlatin")) {
+        return QString::fromUtf8("srpski ijekavski");
+    }
     return QString("%1, %2 (%3)").arg(language, country, lang);
 }
 
-Preferences::Preferences(QupZilla* mainClass, QWidget* parent)
+Preferences::Preferences(BrowserWindow* window, QWidget* parent)
     : QDialog(parent)
     , ui(new Ui::Preferences)
-    , p_QupZilla(mainClass)
+    , m_window(window)
     , m_autoFillManager(0)
     , m_pluginsList(0)
     , m_autoFillEnabled(false)
@@ -122,10 +144,10 @@ Preferences::Preferences(QupZilla* mainClass, QWidget* parent)
     Settings settings;
     //GENERAL URLs
     settings.beginGroup("Web-URL-Settings");
-    m_homepage = settings.value("homepage", "qupzilla:start").toString();
-    m_newTabUrl = settings.value("newTabUrl", "qupzilla:speeddial").toString();
-    ui->homepage->setText(m_homepage);
-    ui->newTabUrl->setText(m_newTabUrl);
+    m_homepage = settings.value("homepage", QUrl(QSL("qupzilla:start"))).toUrl();
+    m_newTabUrl = settings.value("newTabUrl", QUrl(QSL("qupzilla:speeddial"))).toUrl();
+    ui->homepage->setText(m_homepage.toEncoded());
+    ui->newTabUrl->setText(m_newTabUrl.toEncoded());
     int afterLaunch = settings.value("afterLaunch", 3).toInt();
     settings.endGroup();
     ui->afterLaunch->setCurrentIndex(afterLaunch);
@@ -152,13 +174,13 @@ Preferences::Preferences(QupZilla* mainClass, QWidget* parent)
 #endif
 
     ui->newTabFrame->setVisible(false);
-    if (m_newTabUrl.isEmpty()) {
+    if (m_newTabUrl.isEmpty() || m_newTabUrl.toString() == QL1S("about:blank")) {
         ui->newTab->setCurrentIndex(0);
     }
     else if (m_newTabUrl == m_homepage) {
         ui->newTab->setCurrentIndex(1);
     }
-    else if (m_newTabUrl == QLatin1String("qupzilla:speeddial")) {
+    else if (m_newTabUrl.toString() == QL1S("qupzilla:speeddial")) {
         ui->newTab->setCurrentIndex(2);
     }
     else {
@@ -169,7 +191,7 @@ Preferences::Preferences(QupZilla* mainClass, QWidget* parent)
     afterLaunchChanged(ui->afterLaunch->currentIndex());
     connect(ui->afterLaunch, SIGNAL(currentIndexChanged(int)), this, SLOT(afterLaunchChanged(int)));
     connect(ui->newTab, SIGNAL(currentIndexChanged(int)), this, SLOT(newTabChanged(int)));
-    if (p_QupZilla) {
+    if (m_window) {
         connect(ui->useCurrentBut, SIGNAL(clicked()), this, SLOT(useActualHomepage()));
         connect(ui->newTabUseCurrent, SIGNAL(clicked()), this, SLOT(useActualNewTab()));
     }
@@ -177,43 +199,29 @@ Preferences::Preferences(QupZilla* mainClass, QWidget* parent)
         ui->useCurrentBut->setEnabled(false);
         ui->newTabUseCurrent->setEnabled(false);
     }
-    //PROFILES
-    m_actProfileName = mApp->currentProfilePath();
-    m_actProfileName = m_actProfileName.left(m_actProfileName.length() - 1);
-    m_actProfileName = m_actProfileName.mid(m_actProfileName.lastIndexOf(QLatin1Char('/')));
-    m_actProfileName.remove(QLatin1Char('/'));
 
-    ui->activeProfile->setText("<b>" + m_actProfileName + "</b>");
+    // PROFILES
+    ProfileManager profileManager;
+    QString startingProfile = profileManager.startingProfile();
+    ui->activeProfile->setText("<b>" + profileManager.currentProfile() + "</b>");
+    ui->startProfile->addItem(startingProfile);
 
-    QSettings profileSettings(mApp->PROFILEDIR + "profiles/profiles.ini", QSettings::IniFormat);
-    QString actProfileName = profileSettings.value("Profiles/startProfile", "default").toString();
-
-    ui->startProfile->addItem(actProfileName);
-    QDir profilesDir(mApp->PROFILEDIR + "profiles/");
-    QStringList list_ = profilesDir.entryList(QDir::Dirs | QDir::NoDotAndDotDot);
-    foreach (const QString &name, list_) {
-        if (actProfileName == name) {
-            continue;
+    foreach (const QString &name, profileManager.availableProfiles()) {
+        if (startingProfile != name) {
+            ui->startProfile->addItem(name);
         }
-
-        ui->startProfile->addItem(name);
     }
+
     connect(ui->createProfile, SIGNAL(clicked()), this, SLOT(createProfile()));
     connect(ui->deleteProfile, SIGNAL(clicked()), this, SLOT(deleteProfile()));
-    connect(ui->startProfile, SIGNAL(currentIndexChanged(QString)), this, SLOT(startProfileIndexChanged(QString)));
-    startProfileIndexChanged(ui->startProfile->currentText());
+    connect(ui->startProfile, SIGNAL(currentIndexChanged(int)), this, SLOT(startProfileIndexChanged(int)));
+    startProfileIndexChanged(ui->startProfile->currentIndex());
 
     //APPEREANCE
     settings.beginGroup("Browser-View-Settings");
     ui->showStatusbar->setChecked(settings.value("showStatusBar", true).toBool());
-    if (p_QupZilla) {
-        ui->showBookmarksToolbar->setChecked(p_QupZilla->bookmarksToolbar()->isVisible());
-        ui->showNavigationToolbar->setChecked(p_QupZilla->navigationBar()->isVisible());
-    }
-    else {
-        ui->showBookmarksToolbar->setChecked(settings.value("showBookmarksToolbar", true).toBool());
-        ui->showNavigationToolbar->setChecked(settings.value("showNavigationToolbar", true).toBool());
-    }
+    ui->showBookmarksToolbar->setChecked(settings.value("showBookmarksToolbar", true).toBool());
+    ui->showNavigationToolbar->setChecked(settings.value("showNavigationToolbar", true).toBool());
     ui->showHome->setChecked(settings.value("showHomeButton", true).toBool());
     ui->showBackForward->setChecked(settings.value("showBackForwardButtons", true).toBool());
     ui->showAddTabButton->setChecked(settings.value("showAddTabButton", false).toBool());
@@ -234,11 +242,12 @@ Preferences::Preferences(QupZilla* mainClass, QWidget* parent)
     ui->openNewEmptyTabAfterActive->setChecked(settings.value("newEmptyTabAfterActive", false).toBool());
     ui->alwaysSwitchTabsWithWheel->setChecked(settings.value("AlwaysSwitchTabsWithWheel", false).toBool());
     ui->switchToNewTabs->setChecked(settings.value("OpenNewTabsSelected", false).toBool());
-    ui->dontQuitOnTab->setChecked(settings.value("dontQuitWithOneTab", false).toBool());
+    ui->dontCloseOnLastTab->setChecked(settings.value("dontCloseWithOneTab", false).toBool());
     ui->askWhenClosingMultipleTabs->setChecked(settings.value("AskOnClosing", false).toBool());
-    ui->closedInsteadOpened->setChecked(settings.value("closedInsteadOpenedTabs", false).toBool());
+    ui->showClosedTabsButton->setChecked(settings.value("showClosedTabsButton", false).toBool());
     ui->showTabPreviews->setChecked(settings.value("showTabPreviews", false).toBool());
     ui->animatedTabPreviews->setChecked(settings.value("tabPreviewAnimationsEnabled", true).toBool());
+    ui->showCloseOnInactive->setCurrentIndex(settings.value("showCloseOnInactiveTabs", 0).toInt());
     settings.endGroup();
 
     connect(ui->showTabPreviews, SIGNAL(toggled(bool)), this, SLOT(showTabPreviewsChanged(bool)));
@@ -260,7 +269,7 @@ Preferences::Preferences(QupZilla* mainClass, QWidget* parent)
     bool pbInABuseCC = settings.value("UseCustomProgressColor", false).toBool();
     ui->checkBoxCustomProgressColor->setChecked(pbInABuseCC);
     ui->progressBarColorSelector->setEnabled(pbInABuseCC);
-    QColor pbColor = settings.value("CustomProgressColor", p_QupZilla->palette().color(QPalette::Highlight)).value<QColor>();
+    QColor pbColor = settings.value("CustomProgressColor", palette().color(QPalette::Highlight)).value<QColor>();
     setProgressBarColorIcon(pbColor);
     connect(ui->customColorToolButton, SIGNAL(clicked(bool)), SLOT(selectCustomProgressBarColor()));
     connect(ui->resetProgressBarcolor, SIGNAL(clicked()), SLOT(setProgressBarColorIcon()));
@@ -270,7 +279,7 @@ Preferences::Preferences(QupZilla* mainClass, QWidget* parent)
     ui->searchWithDefaultEngine->setChecked(settings.value("SearchWithDefaultEngine", false).toBool());
     settings.endGroup();
 
-    //BROWSING
+    // BROWSING
     settings.beginGroup("Web-Browser-Settings");
     ui->allowPlugins->setChecked(settings.value("allowFlash", true).toBool());
     ui->allowJavaScript->setChecked(settings.value("allowJavaScript", true).toBool());
@@ -283,10 +292,15 @@ Preferences::Preferences(QupZilla* mainClass, QWidget* parent)
     ui->animateScrolling->setChecked(settings.value("AnimateScrolling", true).toBool());
     ui->printEBackground->setChecked(settings.value("PrintElementBackground", true).toBool());
     ui->wheelScroll->setValue(settings.value("wheelScrollLines", qApp->wheelScrollLines()).toInt());
-    ui->defaultZoom->setValue(settings.value("DefaultZoom", 100).toInt());
     ui->xssAuditing->setChecked(settings.value("XSSAuditing", false).toBool());
     ui->formsUndoRedo->setChecked(settings.value("enableFormsUndoRedo", false).toBool());
 
+    foreach (int level, WebView::zoomLevels()) {
+        ui->defaultZoomLevel->addItem(QString("%1%").arg(level));
+    }
+    ui->defaultZoomLevel->setCurrentIndex(settings.value("DefaultZoomLevel", WebView::zoomLevels().indexOf(100)).toInt());
+    ui->closeAppWithCtrlQ->setChecked(settings.value("closeAppWithCtrlQ", true).toBool());
+
     //Cache
     ui->pagesInCache->setValue(settings.value("maximumCachedPages", 3).toInt());
     connect(ui->pagesInCache, SIGNAL(valueChanged(int)), this, SLOT(pageCacheValueChanged(int)));
@@ -295,7 +309,7 @@ Preferences::Preferences(QupZilla* mainClass, QWidget* parent)
     ui->allowCache->setChecked(settings.value("AllowLocalCache", true).toBool());
     ui->cacheMB->setValue(settings.value("LocalCacheSize", 50).toInt());
     ui->MBlabel->setText(settings.value("LocalCacheSize", 50).toString() + " MB");
-    ui->cachePath->setText(settings.value("CachePath", QString("%1networkcache/").arg(mApp->currentProfilePath())).toString());
+    ui->cachePath->setText(settings.value("CachePath", mApp->networkCache()->cacheDirectory()).toString());
     connect(ui->allowCache, SIGNAL(clicked(bool)), this, SLOT(allowCacheChanged(bool)));
     connect(ui->cacheMB, SIGNAL(valueChanged(int)), this, SLOT(cacheValueChanged(int)));
     connect(ui->changeCachePath, SIGNAL(clicked()), this, SLOT(changeCachePathClicked()));
@@ -321,7 +335,7 @@ Preferences::Preferences(QupZilla* mainClass, QWidget* parent)
     ui->deleteHtml5storageOnClose->setChecked(settings.value("deleteHTML5StorageOnClose", false).toBool());
     connect(ui->html5storage, SIGNAL(toggled(bool)), this, SLOT(allowHtml5storageChanged(bool)));
     // Other
-    ui->doNotTrack->setChecked(settings.value("DoNotTrack", true).toBool());
+    ui->doNotTrack->setChecked(settings.value("DoNotTrack", false).toBool());
     ui->sendReferer->setChecked(settings.value("SendReferer", true).toBool());
 
     //CSS Style
@@ -354,23 +368,25 @@ Preferences::Preferences(QupZilla* mainClass, QWidget* parent)
 
     //FONTS
     settings.beginGroup("Browser-Fonts");
-    ui->fontStandard->setCurrentFont(QFont(settings.value("StandardFont", mApp->webSettings()->fontFamily(QWebSettings::StandardFont)).toString()));
-    ui->fontCursive->setCurrentFont(QFont(settings.value("CursiveFont", mApp->webSettings()->fontFamily(QWebSettings::CursiveFont)).toString()));
-    ui->fontFantasy->setCurrentFont(QFont(settings.value("FantasyFont", mApp->webSettings()->fontFamily(QWebSettings::FantasyFont)).toString()));
-    ui->fontFixed->setCurrentFont(QFont(settings.value("FixedFont", mApp->webSettings()->fontFamily(QWebSettings::FixedFont)).toString()));
-    ui->fontSansSerif->setCurrentFont(QFont(settings.value("SansSerifFont", mApp->webSettings()->fontFamily(QWebSettings::SansSerifFont)).toString()));
-    ui->fontSerif->setCurrentFont(QFont(settings.value("SerifFont", mApp->webSettings()->fontFamily(QWebSettings::SerifFont)).toString()));
+    QWebSettings* webSettings = QWebSettings::globalSettings();
+    ui->fontStandard->setCurrentFont(QFont(settings.value("StandardFont", webSettings->fontFamily(QWebSettings::StandardFont)).toString()));
+    ui->fontCursive->setCurrentFont(QFont(settings.value("CursiveFont", webSettings->fontFamily(QWebSettings::CursiveFont)).toString()));
+    ui->fontFantasy->setCurrentFont(QFont(settings.value("FantasyFont", webSettings->fontFamily(QWebSettings::FantasyFont)).toString()));
+    ui->fontFixed->setCurrentFont(QFont(settings.value("FixedFont", webSettings->fontFamily(QWebSettings::FixedFont)).toString()));
+    ui->fontSansSerif->setCurrentFont(QFont(settings.value("SansSerifFont", webSettings->fontFamily(QWebSettings::SansSerifFont)).toString()));
+    ui->fontSerif->setCurrentFont(QFont(settings.value("SerifFont", webSettings->fontFamily(QWebSettings::SerifFont)).toString()));
 
-    ui->sizeDefault->setValue(settings.value("DefaultFontSize", mApp->webSettings()->fontSize(QWebSettings::DefaultFontSize)).toInt());
-    ui->sizeFixed->setValue(settings.value("FixedFontSize", mApp->webSettings()->fontSize(QWebSettings::DefaultFixedFontSize)).toInt());
-    ui->sizeMinimum->setValue(settings.value("MinimumFontSize", mApp->webSettings()->fontSize(QWebSettings::MinimumFontSize)).toInt());
-    ui->sizeMinimumLogical->setValue(settings.value("MinimumLogicalFontSize", mApp->webSettings()->fontSize(QWebSettings::MinimumLogicalFontSize)).toInt());
+    ui->sizeDefault->setValue(settings.value("DefaultFontSize", webSettings->fontSize(QWebSettings::DefaultFontSize)).toInt());
+    ui->sizeFixed->setValue(settings.value("FixedFontSize", webSettings->fontSize(QWebSettings::DefaultFixedFontSize)).toInt());
+    ui->sizeMinimum->setValue(settings.value("MinimumFontSize", webSettings->fontSize(QWebSettings::MinimumFontSize)).toInt());
+    ui->sizeMinimumLogical->setValue(settings.value("MinimumLogicalFontSize", webSettings->fontSize(QWebSettings::MinimumLogicalFontSize)).toInt());
     settings.endGroup();
 
     //KEYBOARD SHORTCUTS
     settings.beginGroup("Shortcuts");
     ui->switchTabsAlt->setChecked(settings.value("useTabNumberShortcuts", true).toBool());
     ui->loadSpeedDialsCtrl->setChecked(settings.value("useSpeedDialNumberShortcuts", true).toBool());
+    ui->singleKeyShortcuts->setChecked(settings.value("useSingleKeyShortcuts", false).toBool());
     settings.endGroup();
 
     //NOTIFICATIONS
@@ -408,21 +424,25 @@ Preferences::Preferences(QupZilla* mainClass, QWidget* parent)
 
     ui->languages->addItem("English (en_US)");
 
-    QDir lanDir(mApp->TRANSLATIONSDIR);
-    QStringList list = lanDir.entryList(QStringList("*.qm"));
-    foreach (const QString &name, list) {
-        if (name.startsWith(QLatin1String("qt_"))) {
-            continue;
+    const QStringList translationPaths = DataPaths::allPaths(DataPaths::Translations);
+
+    foreach (const QString &path, translationPaths) {
+        QDir lanDir(path);
+        QStringList list = lanDir.entryList(QStringList("*.qm"));
+        foreach (const QString &name, list) {
+            if (name.startsWith(QLatin1String("qt_"))) {
+                continue;
+            }
+
+            QString loc = name;
+            loc.remove(QLatin1String(".qm"));
+
+            if (loc == activeLanguage) {
+                continue;
+            }
+
+            ui->languages->addItem(createLanguageItem(loc), loc);
         }
-
-        QString loc = name;
-        loc.remove(QLatin1String(".qm"));
-
-        if (loc == activeLanguage) {
-            continue;
-        }
-
-        ui->languages->addItem(createLanguageItem(loc), loc);
     }
 
     // Proxy Configuration
@@ -474,11 +494,13 @@ Preferences::Preferences(QupZilla* mainClass, QWidget* parent)
     connect(ui->deleteHtml5storage, SIGNAL(clicked()), this, SLOT(deleteHtml5storage()));
     connect(ui->uaManager, SIGNAL(clicked()), this, SLOT(openUserAgentManager()));
     connect(ui->jsOptionsButton, SIGNAL(clicked()), this, SLOT(openJsOptions()));
+    connect(ui->searchEngines, SIGNAL(clicked()), this, SLOT(openSearchEnginesManager()));
+    connect(ui->spellCheckButton, SIGNAL(clicked()), this, SLOT(openSpellCheckSettings()));
 
     connect(ui->listWidget, SIGNAL(currentItemChanged(QListWidgetItem*,QListWidgetItem*)), this, SLOT(showStackedPage(QListWidgetItem*)));
     ui->listWidget->setItemSelected(ui->listWidget->itemAt(5, 5), true);
 
-    ui->version->setText(" QupZilla v" + QupZilla::VERSION);
+    ui->version->setText(QSL(" QupZilla v") + QL1S(Qz::VERSION));
     ui->listWidget->setCurrentRow(currentSettingsPage);
 
     QDesktopWidget* desktop = QApplication::desktop();
@@ -500,6 +522,16 @@ Preferences::Preferences(QupZilla* mainClass, QWidget* parent)
     ui->html5permissions->setDisabled(true);
 #endif
 
+#ifndef USE_HUNSPELL
+    delete ui->spellCheckLabel;
+    delete ui->spellCheckButton;
+    delete ui->spellCheckLayout;
+#endif
+
+    settings.beginGroup(QSL("Preferences"));
+    restoreGeometry(settings.value(QSL("Geometry")).toByteArray());
+    settings.endGroup();
+
     QzTools::setWmClass("Preferences", this);
 }
 
@@ -575,12 +607,18 @@ void Preferences::allowCacheChanged(bool state)
 
 void Preferences::useActualHomepage()
 {
-    ui->homepage->setText(p_QupZilla->weView()->url().toString());
+    if (!m_window)
+        return;
+
+    ui->homepage->setText(m_window->weView()->url().toString());
 }
 
 void Preferences::useActualNewTab()
 {
-    ui->newTabUrl->setText(p_QupZilla->weView()->url().toString());
+    if (!m_window)
+        return;
+
+    ui->newTabUrl->setText(m_window->weView()->url().toString());
 }
 
 void Preferences::chooseDownPath()
@@ -626,8 +664,8 @@ void Preferences::chooseExternalDownloadManager()
 
 void Preferences::openUserAgentManager()
 {
-    UserAgentDialog dialog(this);
-    dialog.exec();
+    UserAgentDialog* dialog = new UserAgentDialog(this);
+    dialog->open();
 }
 
 void Preferences::downLocChanged(bool state)
@@ -667,35 +705,45 @@ void Preferences::allowHtml5storageChanged(bool stat)
 
 void Preferences::showCookieManager()
 {
-    CookieManager* m = mApp->cookieManager();
-    m->refreshTable();
-
-    m->show();
-    m->raise();
+    CookieManager* dialog = new CookieManager(this);
+    dialog->open();
 }
 
 void Preferences::showHtml5Permissions()
 {
-    HTML5PermissionsDialog dialog(this);
-    dialog.exec();
+    HTML5PermissionsDialog* dialog = new HTML5PermissionsDialog(this);
+    dialog->open();
 }
 
 void Preferences::openSslManager()
 {
     SSLManager* m = new SSLManager(this);
-    m->show();
+    m->open();
 }
 
 void Preferences::openJsOptions()
 {
-    JsOptions options(this);
-    options.exec();
+    JsOptions* dialog = new JsOptions(this);
+    dialog->open();
+}
+
+void Preferences::openSearchEnginesManager()
+{
+    SearchEnginesDialog* dialog = new SearchEnginesDialog(this);
+    dialog->open();
+}
+
+void Preferences::openSpellCheckSettings()
+{
+#ifdef USE_HUNSPELL
+    Speller::instance()->showSettings();
+#endif
 }
 
 void Preferences::showAcceptLanguage()
 {
-    AcceptLanguage a(this);
-    a.exec();
+    AcceptLanguage* dialog = new AcceptLanguage(this);
+    dialog->open();
 }
 
 void Preferences::newTabChanged(int value)
@@ -788,30 +836,26 @@ void Preferences::createProfile()
 {
     QString name = QInputDialog::getText(this, tr("New Profile"), tr("Enter the new profile's name:"));
     name = QzTools::filterCharsFromFilename(name);
+
     if (name.isEmpty()) {
         return;
     }
-    QDir dir(mApp->PROFILEDIR + "profiles/");
-    if (QDir(dir.absolutePath() + "/" + name).exists()) {
+
+    ProfileManager profileManager;
+    int res = profileManager.createProfile(name);
+
+    if (res == -1) {
         QMessageBox::warning(this, tr("Error!"), tr("This profile already exists!"));
         return;
     }
-    if (!dir.mkdir(name)) {
+
+    if (res != 0) {
         QMessageBox::warning(this, tr("Error!"), tr("Cannot create profile directory!"));
         return;
     }
 
-    dir.cd(name);
-    QFile(":data/browsedata.db").copy(dir.absolutePath() + "/browsedata.db");
-    QFile(dir.absolutePath() + "/browsedata.db").setPermissions(QFile::ReadUser | QFile::WriteUser);
-
-    QFile versionFile(dir.absolutePath() + "/version");
-    versionFile.open(QFile::WriteOnly);
-    versionFile.write(QupZilla::VERSION.toUtf8());
-    versionFile.close();
-
-    ui->startProfile->insertItem(0, name);
-    ui->startProfile->setCurrentIndex(0);
+    ui->startProfile->addItem(name);
+    ui->startProfile->setCurrentIndex(ui->startProfile->count() - 1);
 }
 
 void Preferences::deleteProfile()
@@ -823,15 +867,19 @@ void Preferences::deleteProfile()
         return;
     }
 
-    QzTools::removeDir(mApp->PROFILEDIR + "profiles/" + name);
+    ProfileManager profileManager;
+    profileManager.removeProfile(name);
+
     ui->startProfile->removeItem(ui->startProfile->currentIndex());
 }
 
-void Preferences::startProfileIndexChanged(QString index)
+void Preferences::startProfileIndexChanged(int index)
 {
-    ui->deleteProfile->setEnabled(m_actProfileName != index);
+    // Index 0 is current profile
 
-    if (m_actProfileName == index) {
+    ui->deleteProfile->setEnabled(index != 0);
+
+    if (index == 0) {
         ui->cannotDeleteActiveProfileLabel->setText(tr("Note: You cannot delete active profile."));
     }
     else {
@@ -853,15 +901,15 @@ void Preferences::saveSettings()
 {
     Settings settings;
     //GENERAL URLs
-    settings.beginGroup("Web-URL-Settings");
-    settings.setValue("homepage", ui->homepage->text());
+    QUrl homepage = QUrl::fromUserInput(ui->homepage->text());
 
-    QString homepage = ui->homepage->text();
+    settings.beginGroup("Web-URL-Settings");
+    settings.setValue("homepage", homepage);
     settings.setValue("afterLaunch", ui->afterLaunch->currentIndex());
 
     switch (ui->newTab->currentIndex()) {
     case 0:
-        settings.setValue("newTabUrl", QString());
+        settings.setValue("newTabUrl", QUrl(QSL("about:blank")));
         break;
 
     case 1:
@@ -869,11 +917,11 @@ void Preferences::saveSettings()
         break;
 
     case 2:
-        settings.setValue("newTabUrl", "qupzilla:speeddial");
+        settings.setValue("newTabUrl", QUrl(QSL("qupzilla:speeddial")));
         break;
 
     case 3:
-        settings.setValue("newTabUrl", ui->newTabUrl->text());
+        settings.setValue("newTabUrl", QUrl::fromUserInput(ui->newTabUrl->text()));
         break;
 
     default:
@@ -890,7 +938,7 @@ void Preferences::saveSettings()
 
     //WINDOW
     settings.beginGroup("Browser-View-Settings");
-    settings.setValue("showStatusbar", ui->showStatusbar->isChecked());
+    settings.setValue("showStatusBar", ui->showStatusbar->isChecked());
     settings.setValue("showBookmarksToolbar", ui->showBookmarksToolbar->isChecked());
     settings.setValue("showNavigationToolbar", ui->showNavigationToolbar->isChecked());
     settings.setValue("showHomeButton", ui->showHome->isChecked());
@@ -909,11 +957,12 @@ void Preferences::saveSettings()
     settings.setValue("newEmptyTabAfterActive", ui->openNewEmptyTabAfterActive->isChecked());
     settings.setValue("AlwaysSwitchTabsWithWheel", ui->alwaysSwitchTabsWithWheel->isChecked());
     settings.setValue("OpenNewTabsSelected", ui->switchToNewTabs->isChecked());
-    settings.setValue("dontQuitWithOneTab", ui->dontQuitOnTab->isChecked());
+    settings.setValue("dontCloseWithOneTab", ui->dontCloseOnLastTab->isChecked());
     settings.setValue("AskOnClosing", ui->askWhenClosingMultipleTabs->isChecked());
-    settings.setValue("closedInsteadOpenedTabs", ui->closedInsteadOpened->isChecked());
+    settings.setValue("showClosedTabsButton", ui->showClosedTabsButton->isChecked());
     settings.setValue("showTabPreviews", ui->showTabPreviews->isChecked());
     settings.setValue("tabPreviewAnimationsEnabled", ui->animatedTabPreviews->isChecked());
+    settings.setValue("showCloseOnInactiveTabs", ui->showCloseOnInactive->currentIndex());
     settings.endGroup();
 
     //DOWNLOADS
@@ -950,6 +999,7 @@ void Preferences::saveSettings()
     settings.beginGroup("Shortcuts");
     settings.setValue("useTabNumberShortcuts", ui->switchTabsAlt->isChecked());
     settings.setValue("useSpeedDialNumberShortcuts", ui->loadSpeedDialsCtrl->isChecked());
+    settings.setValue("useSingleKeyShortcuts", ui->singleKeyShortcuts->isChecked());
     settings.endGroup();
 
     //BROWSING
@@ -968,9 +1018,10 @@ void Preferences::saveSettings()
     settings.setValue("DoNotTrack", ui->doNotTrack->isChecked());
     settings.setValue("CheckUpdates", ui->checkUpdates->isChecked());
     settings.setValue("LoadTabsOnActivation", ui->dontLoadTabsUntilSelected->isChecked());
-    settings.setValue("DefaultZoom", ui->defaultZoom->value());
+    settings.setValue("DefaultZoomLevel", ui->defaultZoomLevel->currentIndex());
     settings.setValue("XSSAuditing", ui->xssAuditing->isChecked());
     settings.setValue("enableFormsUndoRedo", ui->formsUndoRedo->isChecked());
+    settings.setValue("closeAppWithCtrlQ", ui->closeAppWithCtrlQ->isChecked());
 #ifdef Q_OS_WIN
     settings.setValue("CheckDefaultBrowser", ui->checkDefaultBrowser->isChecked());
 #endif
@@ -1068,9 +1119,8 @@ void Preferences::saveSettings()
     settings.setValue("ProxyExceptions", ui->proxyExceptions->text().split(QLatin1Char(','), QString::SkipEmptyParts));
     settings.endGroup();
 
-    //Profiles
-    QSettings profileSettings(mApp->PROFILEDIR + "profiles/profiles.ini", QSettings::IniFormat);
-    profileSettings.setValue("Profiles/startProfile", ui->startProfile->currentText());
+    ProfileManager profileManager;
+    profileManager.setStartingProfile(ui->startProfile->currentText());
 
     m_pluginsList->save();
     m_themesManager->save();
@@ -1085,6 +1135,8 @@ void Preferences::saveSettings()
 
 Preferences::~Preferences()
 {
+    Settings().setValue(QSL("Preferences/Geometry"), saveGeometry());
+
     delete ui;
     delete m_autoFillManager;
     delete m_pluginsList;
@@ -1096,7 +1148,7 @@ void Preferences::setProgressBarColorIcon(QColor color)
     const int size = style()->pixelMetric(QStyle::PM_ToolBarIconSize);
     QPixmap pm(QSize(size, size));
     if (!color.isValid()) {
-        color = p_QupZilla->palette().color(QPalette::Highlight);
+        color = palette().color(QPalette::Highlight);
     }
     pm.fill(color);
     ui->customColorToolButton->setIcon(pm);
