@@ -484,7 +484,7 @@ void TabWidget::closeTab(int index, bool force)
 
     if (m_menuTabs->isVisible()) {
         QAction* labelAction = m_menuTabs->actions().last();
-        labelAction->setText(tr("Currently you have %n opened tab(s)", "", count() - 1));
+        labelAction->setText(tr("Currently you have %n opened tabs", "", count() - 1));
     }
 
     removeTab(index);
@@ -835,9 +835,8 @@ QByteArray TabWidget::saveState()
 
     for (int i = 0; i < count(); ++i) {
         WebTab* webTab = weTab(i);
-        if (!webTab || webTab->isPinned()) {
+        if (!webTab)
             continue;
-        }
 
         WebTab::SavedTab tab(webTab);
         tabList.append(tab);
@@ -859,20 +858,18 @@ QByteArray TabWidget::saveState()
 
 bool TabWidget::restoreState(const QVector<WebTab::SavedTab> &tabs, int currentTab)
 {
-    Qz::BrowserWindowType type = m_window->windowType();
-
-    if (type == Qz::BW_FirstAppWindow || type == Qz::BW_MacFirstWindow) {
-        restorePinnedTabs();
-    }
-
     for (int i = 0; i < tabs.size(); ++i) {
         WebTab::SavedTab tab = tabs.at(i);
 
-        int index = addView(QUrl(), Qz::NT_CleanSelectedTab);
+        int index = addView(QUrl(), Qz::NT_CleanSelectedTab, false, tab.isPinned);
         weTab(index)->restoreTab(tab);
+
+        if (tab.isPinned)
+            m_tabBar->updatePinnedTabCloseButton(index);
     }
 
     setCurrentIndex(currentTab);
+    QTimer::singleShot(0, m_tabBar, SLOT(ensureVisible(int,int)));
 
     // WebTab is restoring state on showEvent
     weTab()->hide();
