@@ -43,11 +43,9 @@
 
 #if QT_VERSION >= 0x050000
 #include <QUrlQuery>
-#include <qpa/qplatformnativeinterface.h>
-#else
-#include <QX11Info>
 #endif
 #ifdef QZ_WS_X11
+#include <QX11Info>
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
 #endif
@@ -223,26 +221,31 @@ QUrl QzTools::frameUrl(QWebFrame* frame)
 
 QString QzTools::ensureUniqueFilename(const QString &name, const QString &appendFormat)
 {
-    if (!QFile::exists(name)) {
+    Q_ASSERT(appendFormat.contains(QL1S("%1")));
+
+    QFileInfo info(name);
+
+    if (!info.exists())
         return name;
-    }
 
-    QString tmpFileName = name;
+    const QDir dir = info.absoluteDir();
+    const QString fileName = info.fileName();
+
     int i = 1;
-    while (QFile::exists(tmpFileName)) {
-        tmpFileName = name;
-        int index = tmpFileName.lastIndexOf(QLatin1Char('.'));
 
-        QString appendString = appendFormat.arg(i);
-        if (index == -1) {
-            tmpFileName.append(appendString);
-        }
-        else {
-            tmpFileName = tmpFileName.left(index) + appendString + tmpFileName.mid(index);
-        }
+    while (info.exists()) {
+        QString file = fileName;
+        int index = file.lastIndexOf(QL1C('.'));
+        const QString appendString = appendFormat.arg(i);
+        if (index == -1)
+            file.append(appendString);
+        else
+            file = file.left(index) + appendString + file.mid(index);
+        info.setFile(dir, file);
         i++;
     }
-    return tmpFileName;
+
+    return info.absoluteFilePath();
 }
 
 QString QzTools::getFileNameFromUrl(const QUrl &url)
@@ -566,6 +569,15 @@ bool QzTools::isUtf8(const char* string)
     return true;
 }
 
+bool QzTools::containsSpace(const QString &str)
+{
+    Q_FOREACH (const QChar &c, str) {
+        if (c.isSpace())
+            return true;
+    }
+    return false;
+}
+
 QString QzTools::getExistingDirectory(const QString &name, QWidget* parent, const QString &caption, const QString &dir, QFileDialog::Options options)
 {
     Settings settings;
@@ -821,30 +833,28 @@ QString QzTools::escape(const QString &string)
 #endif
 }
 
-void* QzTools::X11Display(const QWidget* widget)
+bool QzTools::isPlatformX11()
 {
-    Q_UNUSED(widget)
-
-#ifdef QZ_WS_X11
-#if QT_VERSION >= 0x050000
-    return qApp->platformNativeInterface()->nativeResourceForWindow("display", widget->windowHandle());
+#if QZ_WS_X11 && QT_VERSION >= 0x050200
+    return QX11Info::isPlatformX11();
+#elif QZ_WS_X11
+    return true;
 #else
-    return QX11Info::display();
+    return false;
 #endif
-#endif
-
-    return 0;
 }
 
 void QzTools::setWmClass(const QString &name, const QWidget* widget)
 {
 #ifdef QZ_WS_X11
-    QByteArray nameData = name.toUtf8();
+    if (isPlatformX11()) {
+        QByteArray nameData = name.toUtf8();
 
-    XClassHint classHint;
-    classHint.res_name = const_cast<char*>(nameData.constData());
-    classHint.res_class = const_cast<char*>("QupZilla");
-    XSetClassHint((Display*)X11Display(widget), widget->winId(), &classHint);
+        XClassHint classHint;
+        classHint.res_name = const_cast<char*>(nameData.constData());
+        classHint.res_class = const_cast<char*>("QupZilla");
+        XSetClassHint(QX11Info::display(), widget->winId(), &classHint);
+    }
 #else
     Q_UNUSED(name)
     Q_UNUSED(widget)
