@@ -37,7 +37,7 @@ PluginSpec PIM_Plugin::pluginSpec()
     PluginSpec spec;
     spec.name = "PIM";
     spec.info = "Personal Information Manager";
-    spec.description = "Adds ability for Qupzilla to store some personal data";
+    spec.description = "Adds ability for QupZilla to store some personal data";
     spec.version = "0.1.2";
     spec.author = QString::fromUtf8("Mladen Pejaković <pejakm@autistici.org>");
     spec.icon = QPixmap(":/PIM/data/PIM.png");
