@@ -1,6 +1,6 @@
 /* ============================================================
 * StatusBarIcons - Extra icons in statusbar for QupZilla
-* Copyright (C) 2013  David Rosca <nowrep@gmail.com>
+* Copyright (C) 2013-2014  David Rosca <nowrep@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -20,19 +20,14 @@
 
 #include <QIcon>
 
-#include "clickablelabel.h"
+#include "sbi_icon.h"
 
-class QWebSettings;
-
-class QupZilla;
-class WebPage;
-
-class SBI_JavaScriptIcon : public ClickableLabel
+class SBI_JavaScriptIcon : public SBI_Icon
 {
     Q_OBJECT
 
 public:
-    explicit SBI_JavaScriptIcon(QupZilla* window);
+    explicit SBI_JavaScriptIcon(BrowserWindow* window);
 
 private slots:
     void showMenu(const QPoint &point);
@@ -42,10 +37,6 @@ private slots:
     void openJavaScriptSettings();
 
 private:
-    WebPage* currentPage();
-    QWebSettings* currentPageSettings();
-
-    QupZilla* p_QupZilla;
     QIcon m_icon;
 };
 
